@@ -133,12 +133,13 @@ def test_hn_nested_simple_tag():
 
 def test_hn_nested_img():
     image_attributes_to_markdown = [
-        ("", ""),
-        ("alt='Alt Text'", "Alt Text"),
-        ("alt='Alt Text' title='Optional title'", "Alt Text"),
+        ("", "", ""),
+        ("alt='Alt Text'", "Alt Text", ""),
+        ("alt='Alt Text' title='Optional title'", "Alt Text", " \"Optional title\""),
     ]
-    for image_attributes, markdown in image_attributes_to_markdown:
-        assert md('<h3>A <img src="/path/to/img.jpg " ' + image_attributes + '/> B</h3>') == '### A ' + markdown + ' B\n\n'
+    for image_attributes, markdown, title in image_attributes_to_markdown:
+        assert md('<h3>A <img src="/path/to/img.jpg" ' + image_attributes + '/> B</h3>') == '### A ' + markdown + ' B\n\n'
+        assert md('<h3>A <img src="/path/to/img.jpg" ' + image_attributes + '/> B</h3>', keep_inline_images_in=['h3']) == '### A ![' + markdown + '](/path/to/img.jpg' + title + ') B\n\n'
 
 
 def test_hn_atx_headings():
@@ -215,3 +216,12 @@ def test_sup():
 def test_lang():
     assert md('<pre>test\n    foo\nbar</pre>', code_language='python') == '\n```python\ntest\n    foo\nbar\n```\n'
     assert md('<pre><code>test\n    foo\nbar</code></pre>', code_language='javascript') == '\n```javascript\ntest\n    foo\nbar\n```\n'
+
+
+def test_lang_callback():
+    def callback(el):
+        return el['class'][0] if el.has_attr('class') else None
+
+    assert md('<pre class="python">test\n    foo\nbar</pre>', code_language_callback=callback) == '\n```python\ntest\n    foo\nbar\n```\n'
+    assert md('<pre class="javascript"><code>test\n    foo\nbar</code></pre>', code_language_callback=callback) == '\n```javascript\ntest\n    foo\nbar\n```\n'
+    assert md('<pre class="javascript"><code class="javascript">test\n    foo\nbar</code></pre>', code_language_callback=callback) == '\n```javascript\ntest\n    foo\nbar\n```\n'
